/* -*- Mode: Java; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
*/

/*
 * A JavaScript implementation of the RSA Data Security, Inc. MD5 Message
 * Digest Algorithm, as defined in RFC 1321.
 * Version 2.1 Copyright (C) Paul Johnston 1999 - 2002.
 * Other contributors: Greg Holt, Andrew Kepert, Ydnar, Lostinet
 * Distributed under the BSD License
 * See http://pajhome.org.uk/crypt/md5 for more info.
 */

/*
 * Configurable variables. You may need to tweak these to be compatible with
 * the server-side, but the defaults work in most cases.
 */
var hexcase = 0;  /* hex output format. 0 - lowercase; 1 - uppercase        */
var b64pad  = ""; /* base-64 pad character. "=" for strict RFC compliance   */
var chrsz   = 8;  /* bits per input character. 8 - ASCII; 16 - Unicode      */

/*
 * These are the functions you'll usually want to call
 * They take string arguments and return either hex or base-64 encoded strings
 */
function hex_md5(s){ return binl2hex(core_md5(str2binl(s), s.length * chrsz));}
function b64_md5(s){ return binl2b64(core_md5(str2binl(s), s.length * chrsz));}
function str_md5(s){ return binl2str(core_md5(str2binl(s), s.length * chrsz));}
function hex_hmac_md5(key, data) { return binl2hex(core_hmac_md5(key, data)); }
function b64_hmac_md5(key, data) { return binl2b64(core_hmac_md5(key, data)); }
function str_hmac_md5(key, data) { return binl2str(core_hmac_md5(key, data)); }

/*
 * Perform a simple self-test to see if the VM is working
 */
function md5_vm_test()
{
  return hex_md5("abc") == "900150983cd24fb0d6963f7d28e17f72";
}

/*
 * Calculate the MD5 of an array of little-endian words, and a bit length
 */
function core_md5(x, len)
{
  /* append padding */
  x[len >> 5] |= 0x80 << ((len) % 32);
  x[(((len + 64) >>> 9) << 4) + 14] = len;

  var a =  1732584193;
  var b = -271733879;
  var c = -1732584194;
  var d =  271733878;

  for(var i = 0; i < x.length; i += 16)
  {
    var olda = a;
    var oldb = b;
    var oldc = c;
    var oldd = d;

    a = md5_ff(a, b, c, d, x[i+ 0], 7 , -680876936);
    d = md5_ff(d, a, b, c, x[i+ 1], 12, -389564586);
    c = md5_ff(c, d, a, b, x[i+ 2], 17,  606105819);
    b = md5_ff(b, c, d, a, x[i+ 3], 22, -1044525330);
    a = md5_ff(a, b, c, d, x[i+ 4], 7 , -176418897);
    d = md5_ff(d, a, b, c, x[i+ 5], 12,  1200080426);
    c = md5_ff(c, d, a, b, x[i+ 6], 17, -1473231341);
    b = md5_ff(b, c, d, a, x[i+ 7], 22, -45705983);
    a = md5_ff(a, b, c, d, x[i+ 8], 7 ,  1770035416);
    d = md5_ff(d, a, b, c, x[i+ 9], 12, -1958414417);
    c = md5_ff(c, d, a, b, x[i+10], 17, -42063);
    b = md5_ff(b, c, d, a, x[i+11], 22, -1990404162);
    a = md5_ff(a, b, c, d, x[i+12], 7 ,  1804603682);
    d = md5_ff(d, a, b, c, x[i+13], 12, -40341101);
    c = md5_ff(c, d, a, b, x[i+14], 17, -1502002290);
    b = md5_ff(b, c, d, a, x[i+15], 22,  1236535329);

    a = md5_gg(a, b, c, d, x[i+ 1], 5 , -165796510);
    d = md5_gg(d, a, b, c, x[i+ 6], 9 , -1069501632);
    c = md5_gg(c, d, a, b, x[i+11], 14,  643717713);
    b = md5_gg(b, c, d, a, x[i+ 0], 20, -373897302);
    a = md5_gg(a, b, c, d, x[i+ 5], 5 , -701558691);
    d = md5_gg(d, a, b, c, x[i+10], 9 ,  38016083);
    c = md5_gg(c, d, a, b, x[i+15], 14, -660478335);
    b = md5_gg(b, c, d, a, x[i+ 4], 20, -405537848);
    a = md5_gg(a, b, c, d, x[i+ 9], 5 ,  568446438);
    d = md5_gg(d, a, b, c, x[i+14], 9 , -1019803690);
    c = md5_gg(c, d, a, b, x[i+ 3], 14, -187363961);
    b = md5_gg(b, c, d, a, x[i+ 8], 20,  1163531501);
    a = md5_gg(a, b, c, d, x[i+13], 5 , -1444681467);
    d = md5_gg(d, a, b, c, x[i+ 2], 9 , -51403784);
    c = md5_gg(c, d, a, b, x[i+ 7], 14,  1735328473);
    b = md5_gg(b, c, d, a, x[i+12], 20, -1926607734);

    a = md5_hh(a, b, c, d, x[i+ 5], 4 , -378558);
    d = md5_hh(d, a, b, c, x[i+ 8], 11, -2022574463);
    c = md5_hh(c, d, a, b, x[i+11], 16,  1839030562);
    b = md5_hh(b, c, d, a, x[i+14], 23, -35309556);
    a = md5_hh(a, b, c, d, x[i+ 1], 4 , -1530992060);
    d = md5_hh(d, a, b, c, x[i+ 4], 11,  1272893353);
    c = md5_hh(c, d, a, b, x[i+ 7], 16, -155497632);
    b = md5_hh(b, c, d, a, x[i+10], 23, -1094730640);
    a = md5_hh(a, b, c, d, x[i+13], 4 ,  681279174);
    d = md5_hh(d, a, b, c, x[i+ 0], 11, -358537222);
    c = md5_hh(c, d, a, b, x[i+ 3], 16, -722521979);
    b = md5_hh(b, c, d, a, x[i+ 6], 23,  76029189);
    a = md5_hh(a, b, c, d, x[i+ 9], 4 , -640364487);
    d = md5_hh(d, a, b, c, x[i+12], 11, -421815835);
    c = md5_hh(c, d, a, b, x[i+15], 16,  530742520);
    b = md5_hh(b, c, d, a, x[i+ 2], 23, -995338651);

    a = md5_ii(a, b, c, d, x[i+ 0], 6 , -198630844);
    d = md5_ii(d, a, b, c, x[i+ 7], 10,  1126891415);
    c = md5_ii(c, d, a, b, x[i+14], 15, -1416354905);
    b = md5_ii(b, c, d, a, x[i+ 5], 21, -57434055);
    a = md5_ii(a, b, c, d, x[i+12], 6 ,  1700485571);
    d = md5_ii(d, a, b, c, x[i+ 3], 10, -1894986606);
    c = md5_ii(c, d, a, b, x[i+10], 15, -1051523);
    b = md5_ii(b, c, d, a, x[i+ 1], 21, -2054922799);
    a = md5_ii(a, b, c, d, x[i+ 8], 6 ,  1873313359);
    d = md5_ii(d, a, b, c, x[i+15], 10, -30611744);
    c = md5_ii(c, d, a, b, x[i+ 6], 15, -1560198380);
    b = md5_ii(b, c, d, a, x[i+13], 21,  1309151649);
    a = md5_ii(a, b, c, d, x[i+ 4], 6 , -145523070);
    d = md5_ii(d, a, b, c, x[i+11], 10, -1120210379);
    c = md5_ii(c, d, a, b, x[i+ 2], 15,  718787259);
    b = md5_ii(b, c, d, a, x[i+ 9], 21, -343485551);

    a = safe_add(a, olda);
    b = safe_add(b, oldb);
    c = safe_add(c, oldc);
    d = safe_add(d, oldd);
  }
  return Array(a, b, c, d);

}

/*
 * These functions implement the four basic operations the algorithm uses.
 */
function md5_cmn(q, a, b, x, s, t)
{
  return safe_add(bit_rol(safe_add(safe_add(a, q), safe_add(x, t)), s),b);
}
function md5_ff(a, b, c, d, x, s, t)
{
  return md5_cmn((b & c) | ((~b) & d), a, b, x, s, t);
}
function md5_gg(a, b, c, d, x, s, t)
{
  return md5_cmn((b & d) | (c & (~d)), a, b, x, s, t);
}
function md5_hh(a, b, c, d, x, s, t)
{
  return md5_cmn(b ^ c ^ d, a, b, x, s, t);
}
function md5_ii(a, b, c, d, x, s, t)
{
  return md5_cmn(c ^ (b | (~d)), a, b, x, s, t);
}

/*
 * Calculate the HMAC-MD5, of a key and some data
 */
function core_hmac_md5(key, data)
{
  var bkey = str2binl(key);
  if(bkey.length > 16) bkey = core_md5(bkey, key.length * chrsz);

  var ipad = Array(16), opad = Array(16);
  for(var i = 0; i < 16; i++)
  {
    ipad[i] = bkey[i] ^ 0x36363636;
    opad[i] = bkey[i] ^ 0x5C5C5C5C;
  }

  var hash = core_md5(ipad.concat(str2binl(data)), 512 + data.length * chrsz);
  return core_md5(opad.concat(hash), 512 + 128);
}

/*
 * Add integers, wrapping at 2^32. This uses 16-bit operations internally
 * to work around bugs in some JS interpreters.
 */
function safe_add(x, y)
{
  var lsw = (x & 0xFFFF) + (y & 0xFFFF);
  var msw = (x >> 16) + (y >> 16) + (lsw >> 16);
  return (msw << 16) | (lsw & 0xFFFF);
}

/*
 * Bitwise rotate a 32-bit number to the left.
 */
function bit_rol(num, cnt)
{
  return (num << cnt) | (num >>> (32 - cnt));
}

/*
 * Convert a string to an array of little-endian words
 * If chrsz is ASCII, characters >255 have their hi-byte silently ignored.
 */
function str2binl(str)
{
  var bin = Array();
  var mask = (1 << chrsz) - 1;
  for(var i = 0; i < str.length * chrsz; i += chrsz)
    bin[i>>5] |= (str.charCodeAt(i / chrsz) & mask) << (i%32);
  return bin;
}

/*
 * Convert an array of little-endian words to a string
 */
function binl2str(bin)
{
  var str = "";
  var mask = (1 << chrsz) - 1;
  for(var i = 0; i < bin.length * 32; i += chrsz)
    str += String.fromCharCode((bin[i>>5] >>> (i % 32)) & mask);
  return str;
}

/*
 * Convert an array of little-endian words to a hex string.
 */
function binl2hex(binarray)
{
  var hex_tab = hexcase ? "0123456789ABCDEF" : "0123456789abcdef";
  var str = "";
  for(var i = 0; i < binarray.length * 4; i++)
  {
    str += hex_tab.charAt((binarray[i>>2] >> ((i%4)*8+4)) & 0xF) +
           hex_tab.charAt((binarray[i>>2] >> ((i%4)*8  )) & 0xF);
  }
  return str;
}

/*
 * Convert an array of little-endian words to a base-64 string
 */
function binl2b64(binarray)
{
  var tab = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
  var str = "";
  for(var i = 0; i < binarray.length * 4; i += 3)
  {
    var triplet = (((binarray[i   >> 2] >> 8 * ( i   %4)) & 0xFF) << 16)
                | (((binarray[i+1 >> 2] >> 8 * ((i+1)%4)) & 0xFF) << 8 )
                |  ((binarray[i+2 >> 2] >> 8 * ((i+2)%4)) & 0xFF);
    for(var j = 0; j < 4; j++)
    {
      if(i * 8 + j * 6 > binarray.length * 32) str += b64pad;
      else str += tab.charAt((triplet >> 6*(3-j)) & 0x3F);
    }
  }
  return str;
}



/*
 *
 * The contents of this file below this section
 * are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation.  Portions created by Netscape are
 * Copyright (C) 1998 Netscape Communications Corporation. All
 * Rights Reserved.
 *
 * Contributor(s):
 *   Jerry Liu <jerry@purplebunny.com>
 */

var version = "1.0.0";
var mRank = null;
var mWin = null;
var mState = 0;
var mLastURL = null;
var mLastDomain = null;
var mLastPR = 0;
var mNewWin = 0;
var mRequest = null;
var mRequest2 = null;
var barprefs = null;
var initialized = 0;

function doCheck2() { 
  var keywords = document.getElementById("searchwords2").value;
  if (keywords !== "") {
   searchPage();
   }
  else
  {
    alert('Please fill in one or more words in search text box');
  }
}

function init() {
  	barprefs=Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("purplebunny.");

    var preferencesService = Components.classes["@mozilla.org/preferences-service;1"].getService( Components.interfaces.nsIPrefService );
    var branch = preferencesService.getBranch( "extensions.purplebunny." );
  	
    if( !branch.prefHasUserValue( "purplebunny.bar" ) )
    {
        branch.setCharPref( "purplebunny.bar", "status-bar" );
    }
    if( !branch.prefHasUserValue( "purplebunny.bar" ) )
    {
        branch.setBoolPref( "purplebunny.insertafter", "insertleft" );
    }
    moveBox( branch );

	mRank = document.getElementById( "page-status" );

	if( branch.prefHasUserValue( "purplebunny.advanced" ) )
	{
		var advanced = branch.getIntPref( "purplebunny.advanced" );
		mState = advanced;
  		branch.setIntPref( "page-statuspref.state", mState );
  		var showgoogle = document.getElementById( "showPageStatus" );
  		showgoogle.setAttribute( "checked", mState ? "true" : "false" );
	}

	if( branch.prefHasUserValue( "purplebunny.newWin" ) )
	{
		var advanced = branch.getIntPref( "purplebunny.newWin" );
		mNewWin = advanced;
  		branch.setIntPref( "page-newwin.state", mNewWin );
  		var showgoogle2 = document.getElementById( "openNewWindow" );
  		showgoogle2.setAttribute("checked", mNewWin ? "true" : "false");
	}

	initialized = 1;
  	return;
}


function doClean() {
	document.getElementById('searchwords2').value = "";
	document.getElementById('queryTextbox').value = "";
}

function HandleKeyEvent(inEvent) {   //Contributed by EasySearch project developers
        if(inEvent.keyCode == 13) {
                //default 0 = this window
                var SearchWType = 0;

                //if ctrl set = 1 = in tab
                if(inEvent.ctrlKey) {
                        SearchWType = 1;
                }

                //if shift set = 2 = in new window
                if(inEvent.shiftKey) {
                        SearchWType = 2;
                }

                doMSD(SearchWType);
        }
}

function openUrl2( url )
{
	window.openDialog(url, "", "chrome,modal,resizable,close");
}

function openUrlWin( url )
{
	window.open(url, "", "resizable,close,scrollbars,menubar,toolbar,location,personalbar,status");
}

function openUrl( url )
{
	var tab = window.openNewTabWith(url);
  //var browser = document.getElementById( "content" );
//const kWindowMediatorContractID = "@mozilla.org/appshell/window-mediator;1";
//const kWindowMediatorIID = Components.interfaces.nsIWindowMediator;
//const kWindowMediator = Components.classes[kWindowMediatorContractID].getService(kWindowMediatorIID);
//var browserWindow = kWindowMediator.getMostRecentWindow("navigator:browser");
//var browser = browserWindow.getBrowser();
  //var browser = getBrowser( );
  //var tab = browser.addTab( url, getReferrer( document ) );
  //browser.selectedTab = tab;
}

function writePageComments(x)
{
  	var title = new String( window._content.document.title );
  	var url = new String( window._content.document.location );
  	//url = url.replace( /\?.*$/g, "?" );

  	var link = "http://www.purplebunny.com/forum.php?url=" + encodeURIComponent(url) + "&title=" + encodeURIComponent(title) + "&v=" + version;
	if (mNewWin == 1)
	{
  		openUrlWin( link );
	}
	else
	{
  		openUrl( link );
	}
}

function readPageComments(x)
{
  	var title = new String( window._content.document.title );
  	var url = new String( window._content.document.location );
  	//url = url.replace( /\?.*$/g, "?" );

  	var link = "http://www.purplebunny.com/forum.php?mode=v&url=" + encodeURIComponent(url) + "&title=" + encodeURIComponent(title) + "&v=" + version;
	if (mNewWin == 1)
	{
  		openUrlWin( link );
	}
	else
	{
  		openUrl( link );
	}
}

function readRecentComments()
{
  	var link = "http://www.purplebunny.com/bbs/index2.php";
	if (mNewWin == 1)
	{
  		openUrlWin( link );
	}
	else
	{
  		openUrl( link );
	}
}

function seeMembers()
{
  	var link = "http://www.purplebunny.com/bbs/memberlist.php";
	if (mNewWin == 1)
	{
  		openUrlWin( link );
	}
	else
	{
  		openUrl( link );
	}
}

function readSiteComments()
{
  	var url = new String( window._content.document.location );
  	//url = url.replace( /\?.*$/g, "?" );

  	var link = "http://www.purplebunny.com/site.php?url=" + encodeURIComponent(url) + "&v=" + version;
	if (mNewWin == 1)
	{
  		openUrlWin( link );
	}
	else
	{
  		openUrl( link );
	}
}

function search4Comments(  )
{
  	var url = new String( window._content.document.location );
  	var title = new String( window._content.document.title );
  	var link = "http://www.purplebunny.com/bbs/pagestatus.php?u=" + encodeURIComponent(url) + "&v=" + version + "&t=" + encodeURIComponent(title);
  	openUrl2( link );
}

function searchSite(  )
{
  	var currentHost = new String( window._content.document.location.hostname );
  	var keywords = document.getElementById("searchwords2").value;
  	var link = "http://www.purplebunny.com/bbs/search.php?mode=results&search_keywords=" + encodeURIComponent(keywords) + "&search_forum=" + encodeURIComponent(currentHost) + "&v=" + version;
	if (mNewWin == 1)
	{
  		openUrlWin( link );
	}
	else
	{
  		openUrl( link );
	}
}

function searchPage(  )
{
  	var keywords = document.getElementById("searchwords2").value;
	var link = "http://www.purplebunny.com/bbs/search.php?mode=results&search_keywords=" + encodeURIComponent(keywords) + "&v=" + version;
	if (mNewWin == 1)
	{
  		openUrlWin( link );
	}
	else
	{
  		openUrl( link );
	}
}

function showSearch(  )
{
	var link = "http://www.purplebunny.com/bbs/search.php?v=" + version;
  	openUrl( link );
}

function showAbout2()
{
	window.openDialog( "chrome://purplebunny/content/about.xul", "searchstatus-about-dialog", "centerscreen,chrome,modal" );
}

function showAbout() {
	window.openDialog("chrome://purplebunny/content/about.xul","showmore","chrome");
}

/*
function showOptions2()
{
	window.openDialog( "chrome://purplebunny/content/options/options.xul", "searchstatus-options-dialog", "centerscreen,chrome,modal" );
}
*/

function showOptions() {
    	window.openDialog("chrome://purplebunny/content/options2.xul", "pbbar-options-dialog", "centerscreen,chrome,modal");
}

window.addEventListener( "load", function() {ssLoad();}, true );
window.addEventListener( "focus", function() {ssFocus();}, true );

function ssLoad()
{

  	initStatus();
}

function ssFocus()
{
	if (initialized == 0)
	{
		init();
	}
  	initStatus();
}

function resetStatus()
{
  	var showgoogle = document.getElementById( "showPageStatus" );
  	showgoogle.setAttribute( "checked", mState ? "true" : "false" );	
  	var showgoogle2 = document.getElementById( "openNewWindow" );
  	showgoogle2.setAttribute( "checked", mNewWin ? "true" : "false" );	
  	
  	var url = window._content.document.location;
  	
  	if( mState == 0 )
  	{
  		mRank.setAttribute( "hidden", "true" );
  	}
  	else 
  	{
  		mRank.setAttribute( "hidden", "false" );
  		
  		if( url == mLastURL )
  		{
//  			mRank.setAttribute( "status", mLastPR );
  		  	if( mLastPR == -1 )
  		  	{
  			}
  			else
  			{
  			}
  		}
  		else
  		{
  		  initStatus();	
  		}
  	}
}

function initStatus()
{
  	var url = window._content.document.location;
	if (mRank == null)
		mRank = document.getElementById( "page-status" );
        

	var preferencesService = Components.classes["@mozilla.org/preferences-service;1"].getService( Components.interfaces.nsIPrefService );
	var branch = preferencesService.getBranch( "extensions.purplebunny." );    	
	// first check to see if the feature has been turned off
  	if( mState == 0 )
  	{
  		mRank.setAttribute( "hidden", "true" );
		return;
  	}
  	else 
  	{
  		mRank.setAttribute( "hidden", "false" );
  	
		// are we on same page?	
  		if( url == mLastURL )
  		{
			mRank.setAttribute( "status", mLastPR );
			return;
		}

		// do we know that this domain has no comments?
		if (mLastPR == 0 && mLastDomain == getDomain(url))
		{
			mRank.setAttribute( "status", mLastPR );
			return;
		}
	}

	// check cache file on server
	var domain = getDomain(url);
	var dir = hex_md5(domain);
  	var link = "http://www.purplebunny.com/8/" + dir.charAt(0) + "/" + domain;
	mRequest = new XMLHttpRequest();
	mRequest.open( "HEAD", link, true );
	mRequest.onreadystatechange = onRequestLoad;
	mRequest.setRequestHeader( "User-Agent", "Mozilla/4.0 (compatible; PB 1.0; Windows XP 5.1)" );
	dm("Heading " + link);
	mRequest.send( null );
	mLastURL = url;
	mLastDomain = domain;
}


function onRequestLoad()
{
  if (mRequest.readyState==4) {

  	var url = window._content.document.location;
	var domain = getDomain(url);
	// check response
	try
	{
		var status = mRequest.status;
	}
	catch (e)
	{
		mLastURL = url;
		mLastDomain = domain;
		mRank.setAttribute( "image", "chrome://purplebunny/content/img/speechpurple.png" );
		mRank.setAttribute( "tooltiptext", "There are no comments about this page. Perhaps you would like to write the first one?" );
		mRank.setAttribute( "status", 0 );
		mLastPR = 0;
		dm(url + " => " + "exception");

		return;
	}
	dm(url + " => " + status);
	if (status != 200)
	{
		mLastURL = url;
		mLastDomain = domain;
		mRank.setAttribute( "image", "chrome://purplebunny/content/img/speechpurple.png" );
		mRank.setAttribute( "tooltiptext", "There are no comments about this page. Perhaps you would like to write the first one?" );
		mRank.setAttribute( "status", 0 );
		mLastPR = 0;
		return;
	}

	// at this point, there are comments - check the server DB
  	var title = new String( window._content.document.title );
	var r = Math.round((Math.random()*9));
  	var link = "http://www.purplebunny.com/bbs/p" + r + ".php?s=1&u=" + encodeURIComponent(new String(url)) + "&t=" + encodeURIComponent(title);
	dm("Requesting " + link);
	mRequest2 = new XMLHttpRequest();
	mRequest2.onload = onRequestLoad2;
	mRequest2.open( "GET", link );
	mRequest2.setRequestHeader( "User-Agent", "Mozilla/4.0 (compatible; PB 1.0; Windows XP 5.1)" );
	mRequest2.send( null );
	mLastURL = url;
	mLastDomain = domain;
}
}

function onRequestLoad2()
{
	var temp = mRequest2.responseText;
	var results = temp.split(" ");
	if (temp.length > 7)
	{
		mRank.setAttribute( "image", "chrome://purplebunny/content/img/speechgray.png" );
		mRank.setAttribute( "tooltiptext", "There is currently no information about comments." );
		mRank.setAttribute( "status", 9 );
		mLastPR = 9;
	}
	else if (results[0] > 0)
	{
		mRank.setAttribute( "image", "chrome://purplebunny/content/img/speechgreen.png" );
		mRank.setAttribute( "tooltiptext", "There are comments about this web page!" );
		mRank.setAttribute( "status", 2 );
		mLastPR = 2;
	}	
	else if (results[1] > 0)
	{
		mRank.setAttribute( "image", "chrome://purplebunny/content/img/speechyellow.png" );
		mRank.setAttribute( "tooltiptext", "There are comments about other pages on this site!" );
		mRank.setAttribute( "status", 1 );
		mLastPR = 1;
	}	
	else 
	{
		mRank.setAttribute( "image", "chrome://purplebunny/content/img/speechpurple.png" );
		mRank.setAttribute( "tooltiptext", "There are no comments about this page. Perhaps you would like to write the first one?" );
		mRank.setAttribute( "status", 0 );
		mLastPR = 0;
	}	
}

  function switchWinState()
  {
	var preferencesService = Components.classes["@mozilla.org/preferences-service;1"].getService( Components.interfaces.nsIPrefService );
	var branch = preferencesService.getBranch( "extensions.purplebunny." );    	
  	if( mNewWin == 0 )
  	{
		branch.setIntPref( "purplebunny.newWin", 1 );
  		branch.setIntPref( "page-newwin.state", 1 );
  	  	mNewWin = 1;
  	}
  	else
  	{
		branch.setIntPref( "purplebunny.newWin", 0 );
  		branch.setIntPref( "page-newwin.state", 0 );
  	  	mNewWin = 0;
  	}
  }

  function switchState()
  {
		var preferencesService = Components.classes["@mozilla.org/preferences-service;1"].getService( Components.interfaces.nsIPrefService );
		var branch = preferencesService.getBranch( "extensions.purplebunny." );    	
  	
  	if( mState == 0 )
  	{
		branch.setIntPref( "purplebunny.advanced", 1 );
  		branch.setIntPref( "page-statuspref.state", 1 );
  	  	mState = 1;
  	  	mRank.setAttribute( "hidden", "false" );
  	}
  	else
  	{
		branch.setIntPref( "purplebunny.advanced", 0 );
  		branch.setIntPref( "page-statuspref.state", 0 );
  	  	mState = 0;
  	  	mRank.setAttribute( "hidden", "true" );
  	}
  	
  	initStatus();
  }

function moveBox( branch )
{
	var topWindow = getTopWindow();
	
	if( !branch.prefHasUserValue( "purplebunny.bar" ) || !branch.prefHasUserValue( "purplebunny.insertafter" ) )
	{
		return;
	}
	
  //check if box is in the right location
  var toolbar = topWindow.document.getElementById( branch.getCharPref( "purplebunny.bar" ) );
  //var nextnode = topWindow.document.getElementById( branch.getCharPref( "purplebunny.nextnode" ) );
  var insertafter = branch.getBoolPref( "purplebunny.insertafter" );
  var ssbar	= topWindow.document.getElementById( "pbbar" );
   
/* 
  // bail if it is in the right place or the prefs are not in sync
  var neighbor = ( (insertafter) ? nextnode.nextSibling : nextnode.previousSibling );
  if( neighbor )
  {
    neighbor = neighbor.getAttribute( "id" );
  }

  if( ( ( neighbor == "pbbar" ) && ( ssbar.parentNode == toolbar ) ) || ( nextnode.parentNode != toolbar ) )
  {
    return;
  }
*/

  //remove us from parent
  ssbar.parentNode.removeChild(ssbar);

/*
  //place box
  if( insertafter ) 
  {
    var next_node = nextnode.nextSibling;
    if( next_node )
    {
      toolbar.insertBefore( ssbar, next_node );
    }
    else
    {
      toolbar.appendChild( ssbar );
    }
  }
  else
  {
    toolbar.insertBefore( ssbar, nextnode );
  }
*/
	var children = toolbar.childNodes;

	if ((children.length == 0) || (insertafter))
		toolbar.appendChild(ssbar);
	else
		toolbar.insertBefore(ssbar, children[0]);

}

function dm(aMessage)
{
	var consoleService = Components.classes["@mozilla.org/consoleservice;1"].getService(Components.interfaces.nsIConsoleService);
  	consoleService.logStringMessage(aMessage);
}

function getDomain(url)
{
	var the_url = new String(url);
	var lead_slashes = the_url.indexOf("//");
	var domain_start = lead_slashes + 2;
	var without_resource = the_url.substring(domain_start, the_url.length);
	var next_slash = without_resource.indexOf("/");
	var domain = without_resource.substring(0, next_slash);
	var without_domain = without_resource.substring(next_slash+1, without_resource.length);
	var next_slash2 = without_domain.indexOf("/");
	var firstlevel = without_domain.substring(0, next_slash2);


	if (firstlevel.charAt(0) == '~')
	{
		domain = domain + "/" + firstlevel;
	}
	dm("URL= " + the_url);
	dm("Domain= " + domain);

	return domain;
}

function getTopWindow()
{
  var windowManager = Components.classes["@mozilla.org/appshell/window-mediator;1"].getService();
  var windowManagerInterface = windowManager.QueryInterface( Components.interfaces.nsIWindowMediator );
  var topWindow = windowManagerInterface.getMostRecentWindow( "navigator:browser" );
  if( !topWindow )
  {
    topWindow = window.openDialog("chrome://browser/content/browser.xul", "_blank", "chrome,all,dialog=no", "about:blank", null, null);
  }

  return topWindow;
}
